/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.crop.clm;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import nl.cloudfarming.client.crop.model.Crop;
import nl.cloudfarming.client.crop.model.CropProvider;
import org.openide.util.lookup.ServiceProvider;

/**
 * A CropProvider provides agrosense with agrosense crops.
 * This one provides AgroSense Crops retrieved by the CLM webservice (ClmUpdater)
 * 
 * @author Gerben Feenstra
 */
@ServiceProvider(service = CropProvider.class)
public class ClmCropProvider implements CropProvider {

    List<Crop> crops = new ArrayList<>();
    private ClmUpdater clmUpdater;
    private long lastUpdated; // Last updated time in ms since epoch
    
    public ClmCropProvider(){
        clmUpdater = new ClmUpdater(this);
        clmUpdater.init();
        this.lastUpdated = clmUpdater.getStoredLastUpdated();
    }

    @Override
    public String getId() {
        return ClmCropProvider.class.toString();
    }

    @Override
    public long getLastUpdated() {
        return lastUpdated;
    }

    @Override
    public List<Crop> getCrops() {
        return crops;
    }

    /**
     * Will be set by the ClmUpdater.
     * Will set a new lastUpdated to the current datetime
     * @param crops 
     */
    void setCrops(List<Crop> crops){        
        this.crops = crops;  
        this.lastUpdated = new Date().getTime();
    }
}
